@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::VERSION = '0.12';
+  $Reply::Plugin::VERSION = '0.13';
 }
 use strict;
 use warnings;
@@ -25,7 +25,7 @@ Reply::Plugin - base class for Reply plugins
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,24 @@ string and returns the modified line.
 Compiles the string of Perl code into a coderef. Takes the line of code as a
 string and a hash of extra parameters, and returns the coderef to be executed.
 The default implementation uses L<Eval::Closure> to compile the given string.
-The extra parameters are passed directly to the C<eval_closure> call.
+
+The extra parameters can be anything that C<eval_closure> supports, as well as
+these additional parameters:
+
+=over 4
+
+=item package
+
+The package to use to evaluate the code within. Defaults to C<main>.
+
+=item environments
+
+A hashref of additional lexical environments to be merged with the main lexical
+environment in the C<environment> key. This allows plugins to ensure that their
+extra additions to the lexical scope remain visible, even if other plugins
+change what "the current lexical scope" means.
+
+=back
 
 =item execute
 
