@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::Defaults::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::Defaults::VERSION = '0.12';
+  $Reply::Plugin::Defaults::VERSION = '0.13';
 }
 
 # XXX Eval::Closure imposes its own hints on things that are eval'ed at the
@@ -32,7 +32,6 @@ sub read_line {
 }
 
 (my $PREFIX = <<'PREFIX') =~ s/__PACKAGE__/__PACKAGE__/ge;
-package main;
 BEGIN {
     $^H = $__PACKAGE__::default_hints;
     %^H = %$__PACKAGE__::default_hinthash;
@@ -46,15 +45,18 @@ sub compile {
 
     my @envs = (
         ($args{environment} ? ($args{environment}) : ()),
-        values %{ $args{environments} },
+        values %{ delete $args{environments} },
     );
 
     if (@envs) {
         $args{environment} = { map { %$_ } @envs }
     }
 
+    my $package = delete $args{package} || 'main';
+    my $prefix = "package $package;\n$PREFIX";
+
     return eval_closure(
-        source      => "sub {\n$PREFIX;\n$line\n}",
+        source      => "sub {\n$prefix;\n$line\n}",
         terse_error => 1,
         %args,
     );
