@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::Packages::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::Packages::VERSION = '0.12';
+  $Reply::Plugin::Packages::VERSION = '0.13';
 }
 use strict;
 use warnings;
@@ -28,7 +28,6 @@ sub mangle_line {
 
     my $package = __PACKAGE__;
     return <<LINE;
-package $self->{package};
 $line
 ;
 BEGIN {
@@ -39,16 +38,16 @@ LINE
 
 sub compile {
     my $self = shift;
-    my ($next, @args) = @_;
+    my ($next, $line, %args) = @_;
+
+    $args{package} = $self->{package};
+
+    my @result = $next->($line, %args);
 
     # XXX it'd be nice to avoid using globals here, but we can't use
     # eval_closure's environment parameter since we need to access the
     # information in a BEGIN block
-    our $package = $self->{package};
-
-    my @result = $next->(@args);
-
-    $self->{package} = $package;
+    $self->{package} = our $package;
 
     return @result;
 }
@@ -65,7 +64,7 @@ Reply::Plugin::Packages - persist the current package between lines
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
